@@ -1,15 +1,18 @@
 module Fog
   module Libvirt
     class Compute
-      class Real
+      module Shared
         def create_volume(pool_name, xml)
           client.lookup_storage_pool_by_name(pool_name).create_vol_xml(xml)
         end
       end
 
+      class Real
+        include Shared
+      end
+
       class Mock
-        def create_volume(pool_name, xml)
-        end
+        include Shared
       end
     end
   end
