@@ -1,7 +1,7 @@
 module Fog
   module Libvirt
     class Compute
-      class Real
+      module Shared
         def list_domains(filter = { })
           data=[]
 
@@ -25,9 +25,7 @@ module Fog
         rescue ::Libvirt::RetrieveError, ::Libvirt::Error
           nil
         end
-      end
 
-      module Shared
         private
 
         def domain_display xml
@@ -48,6 +46,24 @@ module Fog
           xml_elements(xml, "domain/os/boot", "dev")
         end
 
+        def firmware(xml)
+          firmware_from_loader = xml_elements(xml, "domain/os/loader", "type").first
+
+          case firmware_from_loader
+          when 'pflash'
+            'efi'
+          when 'rom'
+            'bios'
+          else
+            xml_elements(xml, "domain/os", "firmware").first || 'bios'
+          end
+        end
+
+        # we rely on the fact that the secure attribute is only present when secure boot is enabled
+        def secure_boot_enabled?(xml)
+          xml_elements(xml, "domain/os/loader", "secure").first == 'yes'
+        end
+
         def domain_interfaces xml
           ifs = xml_elements(xml, "domain/devices/interface")
           ifs.map { |i|
@@ -80,7 +96,9 @@ module Fog
               :boot_order      => boot_order(dom.xml_desc),
               :nics            => domain_interfaces(dom.xml_desc),
               :volumes_path    => domain_volumes(dom.xml_desc),
-              :state           => states[dom.info.state]
+              :state           => states[dom.info.state],
+              :firmware        => firmware(dom.xml_desc),
+              :secure_boot     => secure_boot_enabled?(dom.xml_desc),
             }
           rescue ::Libvirt::RetrieveError, ::Libvirt::Error
             # Catch libvirt exceptions to avoid race conditions involving
@@ -90,34 +108,12 @@ module Fog
         end
       end
 
-      class Mock
-        def list_domains(filter = { })
-          dom1 = mock_domain 'fog-dom1'
-          dom2 = mock_domain 'fog-dom2'
-          dom3 = mock_domain 'a-fog-dom3'
-          [dom1, dom2, dom3]
-        end
+      class Real
+        include Shared
+      end
 
-        def mock_domain name
-          xml = read_xml 'domain.xml'
-          {
-              :id              => "dom.uuid",
-              :uuid            => "dom.uuid",
-              :name            => name,
-              :max_memory_size => 8,
-              :cputime         => 7,
-              :memory_size     => 6,
-              :cpus            => 5,
-              :autostart       => false,
-              :os_type         => "hvm",
-              :active          => false,
-              :vnc_port        => 5910,
-              :boot_order      => boot_order(xml),
-              :nics            => domain_interfaces(xml),
-              :volumes_path    => domain_volumes(xml),
-              :state           => 'shutoff'
-          }
-        end
+      class Mock
+        include Shared
       end
     end
   end
