@@ -1,7 +1,7 @@
 module Fog
   module Libvirt
     class Compute
-      class Real
+      module Shared
         def list_networks(filter = { })
           data=[]
           if filter.keys.empty?
@@ -43,30 +43,12 @@ module Fog
         end
       end
 
-      class Mock
-        def list_networks(filter={ })
-          networks = [ {
-              :uuid        => 'a29146ea-39b2-412d-8f53-239eef117a32',
-              :name        => 'net1',
-              :bridge_name => 'virbr0'
-            },
-            {
-              :uuid        => 'fbd4ac68-cbea-4f95-86ed-22953fd92384',
-              :name        => 'net2',
-              :bridge_name => 'virbr1'
-            }
-          ]
-          return networks if filter.empty?
+      class Real
+        include Shared
+      end
 
-          case filter.keys.first
-            when :uuid
-              [networks.find(:uuid => filter[:uuid]).first]
-            when :name
-              [networks.find(:name => filter[:name]).first]
-            else
-              networks
-          end
-        end
+      class Mock
+        include Shared
       end
     end
   end
