@@ -1,7 +1,7 @@
 module Fog
   module Libvirt
     class Compute
-      class Real
+      module Shared
         def upload_volume(pool_name, volume_name, file_path)
           volume = client.lookup_storage_pool_by_name(pool_name).lookup_volume_by_name(volume_name)
           stream = client.stream
@@ -22,9 +22,12 @@ module Fog
         end
       end
 
+      class Real
+        include Shared
+      end
+
       class Mock
-        def upload_volume(pool_name, volume_name, file_path)
-        end
+        include Shared
       end
     end
   end
